@@ -25,15 +25,14 @@ typedef Eo Efl_Ui_List_View;
  * @ref efl_ui_layout_orientation_get.
  *
  * Items inside this widget can be selected according to the
- * @ref efl_ui_multi_selectable_async_select_mode_get policy, and the selection
- * can be retrieved with
- * @ref efl_ui_multi_selectable_async_selected_iterator_new.
+ * @ref efl_ui_multi_selectable_select_mode_get policy, and the selection can
+ * be retrieved with @ref efl_ui_multi_selectable_selected_ndx_iterator_new.
  *
  * @ingroup Efl_Ui_List_View
  */
 #define EFL_UI_LIST_VIEW_CLASS efl_ui_list_view_class_get()
 
-EWAPI const Efl_Class *efl_ui_list_view_class_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_list_view_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
