@@ -35,7 +35,7 @@ typedef Eo Efl_Ui_Progressbar;
  */
 #define EFL_UI_PROGRESSBAR_CLASS efl_ui_progressbar_class_get()
 
-EWAPI const Efl_Class *efl_ui_progressbar_class_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_progressbar_class_get(void) EINA_CONST;
 
 /**
  * @brief When this mode is enabled the progress bar indicates that there is an
@@ -50,7 +50,7 @@ EWAPI const Efl_Class *efl_ui_progressbar_class_get(void);
  *
  * @ingroup Efl_Ui_Progressbar
  */
-EOAPI void efl_ui_progressbar_infinite_mode_set(Eo *obj, Eina_Bool state);
+EAPI EAPI_WEAK void efl_ui_progressbar_infinite_mode_set(Eo *obj, Eina_Bool state);
 
 /**
  * @brief When this mode is enabled the progress bar indicates that there is an
@@ -66,7 +66,7 @@ EOAPI void efl_ui_progressbar_infinite_mode_set(Eo *obj, Eina_Bool state);
  *
  * @ingroup Efl_Ui_Progressbar
  */
-EOAPI Eina_Bool efl_ui_progressbar_infinite_mode_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_progressbar_infinite_mode_get(const Eo *obj);
 
 /**
  * @brief Whether a textual progress label is shown alongside the progress bar
@@ -84,7 +84,7 @@ EOAPI Eina_Bool efl_ui_progressbar_infinite_mode_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Progressbar
  */
-EOAPI void efl_ui_progressbar_show_progress_label_set(Eo *obj, Eina_Bool show);
+EAPI EAPI_WEAK void efl_ui_progressbar_show_progress_label_set(Eo *obj, Eina_Bool show);
 
 /**
  * @brief Whether a textual progress label is shown alongside the progress bar
@@ -103,7 +103,7 @@ EOAPI void efl_ui_progressbar_show_progress_label_set(Eo *obj, Eina_Bool show);
  *
  * @ingroup Efl_Ui_Progressbar
  */
-EOAPI Eina_Bool efl_ui_progressbar_show_progress_label_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_progressbar_show_progress_label_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
