@@ -13,7 +13,6 @@ typedef Eo Efl_Ui_Timepicker;
 
 
 #endif
-#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Timepicker widget
  *
@@ -21,11 +20,13 @@ typedef Eo Efl_Ui_Timepicker;
  * spinner. User can use the internal spinner to select hour, minute, AM/PM or
  * user can input value using internal entry.
  *
+ * @since 1.23
+ *
  * @ingroup Efl_Ui_Timepicker
  */
 #define EFL_UI_TIMEPICKER_CLASS efl_ui_timepicker_class_get()
 
-EWAPI const Efl_Class *efl_ui_timepicker_class_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_timepicker_class_get(void) EINA_CONST;
 
 /**
  * @brief The current value of time
@@ -38,9 +39,11 @@ EWAPI const Efl_Class *efl_ui_timepicker_class_get(void);
  * @param[in] hour The hour value from 0 to 23.
  * @param[in] min The minute value from 0 to 59.
  *
+ * @since 1.23
+ *
  * @ingroup Efl_Ui_Timepicker
  */
-EOAPI void efl_ui_timepicker_time_set(Eo *obj, int hour, int min);
+EAPI EAPI_WEAK void efl_ui_timepicker_time_set(Eo *obj, int hour, int min);
 
 /**
  * @brief The current value of time
@@ -53,9 +56,11 @@ EOAPI void efl_ui_timepicker_time_set(Eo *obj, int hour, int min);
  * @param[out] hour The hour value from 0 to 23.
  * @param[out] min The minute value from 0 to 59.
  *
+ * @since 1.23
+ *
  * @ingroup Efl_Ui_Timepicker
  */
-EOAPI void efl_ui_timepicker_time_get(const Eo *obj, int *hour, int *min);
+EAPI EAPI_WEAK void efl_ui_timepicker_time_get(const Eo *obj, int *hour, int *min);
 
 /**
  * @brief Control if the Timepicker displays 24 hour time or 12 hour time
@@ -63,11 +68,13 @@ EOAPI void efl_ui_timepicker_time_get(const Eo *obj, int *hour, int *min);
  *
  * @param[in] obj The object.
  * @param[in] is_24hour @c true to display the 24 hour time, @c false to
- * display 12 hour time including AM/PM button.
+ * display 12 hour time including AM/PM label.
+ *
+ * @since 1.23
  *
  * @ingroup Efl_Ui_Timepicker
  */
-EOAPI void efl_ui_timepicker_ampm_set(Eo *obj, Eina_Bool is_24hour);
+EAPI EAPI_WEAK void efl_ui_timepicker_is_24hour_set(Eo *obj, Eina_Bool is_24hour);
 
 /**
  * @brief Control if the Timepicker displays 24 hour time or 12 hour time
@@ -76,19 +83,22 @@ EOAPI void efl_ui_timepicker_ampm_set(Eo *obj, Eina_Bool is_24hour);
  * @param[in] obj The object.
  *
  * @return @c true to display the 24 hour time, @c false to display 12 hour
- * time including AM/PM button.
+ * time including AM/PM label.
+ *
+ * @since 1.23
  *
  * @ingroup Efl_Ui_Timepicker
  */
-EOAPI Eina_Bool efl_ui_timepicker_ampm_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_timepicker_is_24hour_get(const Eo *obj);
 
-EWAPI extern const Efl_Event_Description _EFL_UI_TIMEPICKER_EVENT_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_TIMEPICKER_EVENT_TIME_CHANGED;
 
-/** Called when date is changed
+/** Called when time is changed
+ *
+ * @since 1.23
  *
  * @ingroup Efl_Ui_Timepicker
  */
-#define EFL_UI_TIMEPICKER_EVENT_CHANGED (&(_EFL_UI_TIMEPICKER_EVENT_CHANGED))
-#endif /* EFL_BETA_API_SUPPORT */
+#define EFL_UI_TIMEPICKER_EVENT_TIME_CHANGED (&(_EFL_UI_TIMEPICKER_EVENT_TIME_CHANGED))
 
 #endif
