@@ -34,7 +34,7 @@ typedef struct _Efl_Event_Animator_Tick
  */
 #define EFL_CANVAS_OBJECT_CLASS efl_canvas_object_class_get()
 
-EWAPI const Efl_Class *efl_canvas_object_class_get(void);
+EVAS_API EVAS_API_WEAK const Efl_Class *efl_canvas_object_class_get(void) EINA_CONST;
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
@@ -53,7 +53,7 @@ EWAPI const Efl_Class *efl_canvas_object_class_get(void);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_pointer_mode_by_device_set(Eo *obj, Efl_Input_Device *dev, Efl_Input_Object_Pointer_Mode pointer_mode);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_pointer_mode_by_device_set(Eo *obj, Efl_Input_Device *dev, Efl_Input_Object_Pointer_Mode pointer_mode);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -72,7 +72,7 @@ EOAPI Eina_Bool efl_canvas_object_pointer_mode_by_device_set(Eo *obj, Efl_Input_
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_by_device_get(const Eo *obj, Efl_Input_Device *dev);
+EVAS_API EVAS_API_WEAK Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_by_device_get(const Eo *obj, Efl_Input_Device *dev);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -103,7 +103,7 @@ EOAPI Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_by_device_get
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_pointer_mode_set(Eo *obj, Efl_Input_Object_Pointer_Mode pointer_mode);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_pointer_mode_set(Eo *obj, Efl_Input_Object_Pointer_Mode pointer_mode);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -133,7 +133,7 @@ EOAPI Eina_Bool efl_canvas_object_pointer_mode_set(Eo *obj, Efl_Input_Object_Poi
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
@@ -157,7 +157,7 @@ EOAPI Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_get(const Eo
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_render_op_set(Eo *obj, Efl_Gfx_Render_Op render_op);
+EVAS_API EVAS_API_WEAK void efl_canvas_object_render_op_set(Eo *obj, Efl_Gfx_Render_Op render_op);
 
 /**
  * @brief Render mode to be used for compositing the Evas object.
@@ -181,7 +181,7 @@ EOAPI void efl_canvas_object_render_op_set(Eo *obj, Efl_Gfx_Render_Op render_op)
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Efl_Gfx_Render_Op efl_canvas_object_render_op_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Efl_Gfx_Render_Op efl_canvas_object_render_op_get(const Eo *obj);
 
 /**
  * @brief Clip one object to another.
@@ -227,7 +227,7 @@ EOAPI Efl_Gfx_Render_Op efl_canvas_object_render_op_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_clipper_set(Eo *obj, Efl_Canvas_Object *clipper);
+EVAS_API EVAS_API_WEAK void efl_canvas_object_clipper_set(Eo *obj, Efl_Canvas_Object *clipper);
 
 /**
  * @brief Clip one object to another.
@@ -274,7 +274,7 @@ EOAPI void efl_canvas_object_clipper_set(Eo *obj, Efl_Canvas_Object *clipper);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Efl_Canvas_Object *efl_canvas_object_clipper_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Efl_Canvas_Object *efl_canvas_object_clipper_get(const Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
@@ -292,7 +292,7 @@ EOAPI Efl_Canvas_Object *efl_canvas_object_clipper_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_has_fixed_size_set(Eo *obj, Eina_Bool enable);
+EVAS_API EVAS_API_WEAK void efl_canvas_object_has_fixed_size_set(Eo *obj, Eina_Bool enable);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -312,7 +312,7 @@ EOAPI void efl_canvas_object_has_fixed_size_set(Eo *obj, Eina_Bool enable);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_has_fixed_size_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_has_fixed_size_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
@@ -333,7 +333,7 @@ EOAPI Eina_Bool efl_canvas_object_has_fixed_size_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_repeat_events_set(Eo *obj, Eina_Bool repeat);
+EVAS_API EVAS_API_WEAK void efl_canvas_object_repeat_events_set(Eo *obj, Eina_Bool repeat);
 
 /**
  * @brief Whether an Evas object is to repeat events to objects below it.
@@ -353,7 +353,7 @@ EOAPI void efl_canvas_object_repeat_events_set(Eo *obj, Eina_Bool repeat);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_repeat_events_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_repeat_events_get(const Eo *obj);
 
 /**
  * @brief Indicates that this object is the keyboard event receiver on its
@@ -374,7 +374,7 @@ EOAPI Eina_Bool efl_canvas_object_repeat_events_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_key_focus_set(Eo *obj, Eina_Bool focus);
+EVAS_API EVAS_API_WEAK void efl_canvas_object_key_focus_set(Eo *obj, Eina_Bool focus);
 
 /**
  * @brief Indicates that this object is the keyboard event receiver on its
@@ -396,7 +396,7 @@ EOAPI void efl_canvas_object_key_focus_set(Eo *obj, Eina_Bool focus);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_key_focus_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_key_focus_get(const Eo *obj);
 
 /**
  * @brief Check if this object is focused.
@@ -409,7 +409,7 @@ EOAPI Eina_Bool efl_canvas_object_key_focus_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_seat_focus_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_seat_focus_get(const Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
@@ -425,7 +425,7 @@ EOAPI Eina_Bool efl_canvas_object_seat_focus_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_seat_focus_check(Eo *obj, Efl_Input_Device *seat);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_seat_focus_check(Eo *obj, Efl_Input_Device *seat);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -450,7 +450,7 @@ EOAPI Eina_Bool efl_canvas_object_seat_focus_check(Eo *obj, Efl_Input_Device *se
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_seat_focus_add(Eo *obj, Efl_Input_Device *seat);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_seat_focus_add(Eo *obj, Efl_Input_Device *seat);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -468,7 +468,7 @@ EOAPI Eina_Bool efl_canvas_object_seat_focus_add(Eo *obj, Efl_Input_Device *seat
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_seat_focus_del(Eo *obj, Efl_Input_Device *seat);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_seat_focus_del(Eo *obj, Efl_Input_Device *seat);
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
@@ -489,7 +489,7 @@ EOAPI Eina_Bool efl_canvas_object_seat_focus_del(Eo *obj, Efl_Input_Device *seat
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_precise_is_inside_set(Eo *obj, Eina_Bool precise);
+EVAS_API EVAS_API_WEAK void efl_canvas_object_precise_is_inside_set(Eo *obj, Eina_Bool precise);
 
 /**
  * @brief Whether to use precise (usually expensive) point collision detection
@@ -510,7 +510,7 @@ EOAPI void efl_canvas_object_precise_is_inside_set(Eo *obj, Eina_Bool precise);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_precise_is_inside_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_precise_is_inside_get(const Eo *obj);
 
 /**
  * @brief Whether events on a smart object's member should be propagated up to
@@ -533,7 +533,7 @@ EOAPI Eina_Bool efl_canvas_object_precise_is_inside_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_propagate_events_set(Eo *obj, Eina_Bool propagate);
+EVAS_API EVAS_API_WEAK void efl_canvas_object_propagate_events_set(Eo *obj, Eina_Bool propagate);
 
 /**
  * @brief Whether events on a smart object's member should be propagated up to
@@ -557,7 +557,7 @@ EOAPI void efl_canvas_object_propagate_events_set(Eo *obj, Eina_Bool propagate);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_propagate_events_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_propagate_events_get(const Eo *obj);
 
 /**
  * @brief Whether an Evas object is to pass (ignore) events.
@@ -578,7 +578,7 @@ EOAPI Eina_Bool efl_canvas_object_propagate_events_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_pass_events_set(Eo *obj, Eina_Bool pass);
+EVAS_API EVAS_API_WEAK void efl_canvas_object_pass_events_set(Eo *obj, Eina_Bool pass);
 
 /**
  * @brief Whether an Evas object is to pass (ignore) events.
@@ -600,7 +600,7 @@ EOAPI void efl_canvas_object_pass_events_set(Eo *obj, Eina_Bool pass);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_pass_events_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_pass_events_get(const Eo *obj);
 
 /**
  * @brief Whether or not the given Evas object is to be drawn anti-aliased.
@@ -613,7 +613,7 @@ EOAPI Eina_Bool efl_canvas_object_pass_events_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_anti_alias_set(Eo *obj, Eina_Bool anti_alias);
+EVAS_API EVAS_API_WEAK void efl_canvas_object_anti_alias_set(Eo *obj, Eina_Bool anti_alias);
 
 /**
  * @brief Whether or not the given Evas object is to be drawn anti-aliased.
@@ -626,7 +626,7 @@ EOAPI void efl_canvas_object_anti_alias_set(Eo *obj, Eina_Bool anti_alias);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_anti_alias_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_anti_alias_get(const Eo *obj);
 
 /**
  * @brief List of objects currently clipped by @c obj.
@@ -650,7 +650,7 @@ EOAPI Eina_Bool efl_canvas_object_anti_alias_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Iterator *efl_canvas_object_clipped_objects_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+EVAS_API EVAS_API_WEAK Eina_Iterator *efl_canvas_object_clipped_objects_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 #ifdef EFL_CANVAS_OBJECT_PROTECTED
 /**
@@ -668,7 +668,7 @@ EOAPI Eina_Iterator *efl_canvas_object_clipped_objects_get(const Eo *obj) EFL_TR
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Efl_Canvas_Object *efl_canvas_object_render_parent_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Efl_Canvas_Object *efl_canvas_object_render_parent_get(const Eo *obj);
 #endif
 
 /**
@@ -684,7 +684,7 @@ EOAPI Efl_Canvas_Object *efl_canvas_object_render_parent_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_paragraph_direction_set(Eo *obj, Efl_Text_Bidirectional_Type dir);
+EVAS_API EVAS_API_WEAK void efl_canvas_object_paragraph_direction_set(Eo *obj, Efl_Text_Bidirectional_Type dir);
 
 /**
  * @brief This handles text paragraph direction of the given object. Even if
@@ -700,7 +700,7 @@ EOAPI void efl_canvas_object_paragraph_direction_set(Eo *obj, Efl_Text_Bidirecti
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Efl_Text_Bidirectional_Type efl_canvas_object_paragraph_direction_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Efl_Text_Bidirectional_Type efl_canvas_object_paragraph_direction_get(const Eo *obj);
 
 /**
  * @brief Returns the number of objects clipped by @c obj
@@ -713,7 +713,7 @@ EOAPI Efl_Text_Bidirectional_Type efl_canvas_object_paragraph_direction_get(cons
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI unsigned int efl_canvas_object_clipped_objects_count(const Eo *obj) EINA_WARN_UNUSED_RESULT;
+EVAS_API EVAS_API_WEAK unsigned int efl_canvas_object_clipped_objects_count(const Eo *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Requests @c keyname key events be directed to @c obj.
@@ -749,7 +749,7 @@ EOAPI unsigned int efl_canvas_object_clipped_objects_count(const Eo *obj) EINA_W
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_key_grab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers, Eina_Bool exclusive) EINA_WARN_UNUSED_RESULT;
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_key_grab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers, Eina_Bool exclusive) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Removes the grab on @c keyname key events by @c obj.
@@ -772,7 +772,7 @@ EOAPI Eina_Bool efl_canvas_object_key_grab(Eo *obj, const char *keyname, Efl_Inp
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_key_ungrab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers);
+EVAS_API EVAS_API_WEAK void efl_canvas_object_key_ungrab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers);
 
 /**
  * @brief Disables all rendering on the canvas.
@@ -796,7 +796,7 @@ EOAPI void efl_canvas_object_key_ungrab(Eo *obj, const char *keyname, Efl_Input_
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_no_render_set(Eo *obj, Eina_Bool enable);
+EVAS_API EVAS_API_WEAK void efl_canvas_object_no_render_set(Eo *obj, Eina_Bool enable);
 
 /**
  * @brief Disables all rendering on the canvas.
@@ -821,7 +821,7 @@ EOAPI void efl_canvas_object_no_render_set(Eo *obj, Eina_Bool enable);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_no_render_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_no_render_get(const Eo *obj);
 
 /**
  * @brief Whether the coordinates are logically inside the object.
@@ -840,9 +840,9 @@ EOAPI Eina_Bool efl_canvas_object_no_render_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_coords_inside_get(const Eo *obj, Eina_Position2D pos);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_canvas_object_coords_inside_get(const Eo *obj, Eina_Position2D pos);
 
-EWAPI extern const Efl_Event_Description _EFL_CANVAS_OBJECT_EVENT_ANIMATOR_TICK;
+EVAS_API EVAS_API_WEAK extern const Efl_Event_Description _EFL_CANVAS_OBJECT_EVENT_ANIMATOR_TICK;
 
 /** Animator tick synchronized with screen vsync if possible.
  * @return Efl_Event_Animator_Tick
